==> foundation-2.6.1.tgz: package/TorsosAll/TorsosAll.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const TorsosAll = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M96.117 57.583l-16.185-7.719c3.774-2.373 6.338-7.016 6.338-12.354 0-7.754-5.397-14.034-12.058-14.034-2.289 0-4.403.781-6.223 2.066a24.516 24.516 0 011.701 8.999c0 4.782-1.411 9.317-3.825 13.066a12.296 12.296 0 002.809 2.36l-.01.003 10.426 4.971c2.947 1.427 4.853 4.583 4.853 8.045v13.54h11.148c1.489 0 2.694-1.401 2.694-3.13V60.492c0-1.282-.659-2.42-1.668-2.909zm-64.55-7.758a12.32 12.32 0 002.368-1.987c-2.514-3.781-3.972-8.401-3.972-13.297 0-3.271.646-6.37 1.777-9.17-1.76-1.172-3.773-1.895-5.948-1.895-6.666 0-12.062 6.28-12.062 14.034 0 5.425 2.651 10.12 6.524 12.457l-16.349 7.61c-1.02.479-1.691 1.629-1.691 2.915v12.903c0 1.729 1.209 3.13 2.694 3.13h10.805v-13.54c0-3.503 1.938-6.672 4.943-8.08l10.911-5.08z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M76.94 59.386l-14.077-6.715-5.952-2.84c2.6-1.637 4.711-4.165 6.093-7.21a19.543 19.543 0 001.749-8.081c0-1.642-.26-3.201-.623-4.706-1.771-7.293-7.466-12.665-14.302-12.665-6.708 0-12.316 5.181-14.196 12.266-.434 1.625-.733 3.315-.733 5.105 0 3.109.727 6.008 1.961 8.529 1.427 2.925 3.542 5.337 6.116 6.888l-5.702 2.654-14.534 6.768c-1.262.591-2.092 2.016-2.092 3.606v15.97c0 2.14 1.492 3.875 3.333 3.875h51.691c1.841 0 3.333-1.735 3.333-3.875v-15.97c.001-1.584-.815-2.995-2.065-3.599z"
  }));
});
TorsosAll.displayName = 'TorsosAll';
export const TorsosAllDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/TorsosAll/TorsosAll.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var TorsosAll = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M96.117 57.583l-16.185-7.719c3.774-2.373 6.338-7.016 6.338-12.354 0-7.754-5.397-14.034-12.058-14.034-2.289 0-4.403.781-6.223 2.066a24.516 24.516 0 011.701 8.999c0 4.782-1.411 9.317-3.825 13.066a12.296 12.296 0 002.809 2.36l-.01.003 10.426 4.971c2.947 1.427 4.853 4.583 4.853 8.045v13.54h11.148c1.489 0 2.694-1.401 2.694-3.13V60.492c0-1.282-.659-2.42-1.668-2.909zm-64.55-7.758a12.32 12.32 0 002.368-1.987c-2.514-3.781-3.972-8.401-3.972-13.297 0-3.271.646-6.37 1.777-9.17-1.76-1.172-3.773-1.895-5.948-1.895-6.666 0-12.062 6.28-12.062 14.034 0 5.425 2.651 10.12 6.524 12.457l-16.349 7.61c-1.02.479-1.691 1.629-1.691 2.915v12.903c0 1.729 1.209 3.13 2.694 3.13h10.805v-13.54c0-3.503 1.938-6.672 4.943-8.08l10.911-5.08z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M76.94 59.386l-14.077-6.715-5.952-2.84c2.6-1.637 4.711-4.165 6.093-7.21a19.543 19.543 0 001.749-8.081c0-1.642-.26-3.201-.623-4.706-1.771-7.293-7.466-12.665-14.302-12.665-6.708 0-12.316 5.181-14.196 12.266-.434 1.625-.733 3.315-.733 5.105 0 3.109.727 6.008 1.961 8.529 1.427 2.925 3.542 5.337 6.116 6.888l-5.702 2.654-14.534 6.768c-1.262.591-2.092 2.016-2.092 3.606v15.97c0 2.14 1.492 3.875 3.333 3.875h51.691c1.841 0 3.333-1.735 3.333-3.875v-15.97c.001-1.584-.815-2.995-2.065-3.599z"
  }));
});
TorsosAll.displayName = 'TorsosAll';
export var TorsosAllDimensions = {
  height: 100,
  width: 100
};
